@@ -22,21 +22,11 @@
   pyca/cryptography support will be added in the future.
 """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 import hashlib
 
-import six
-
-import securesystemslib.exceptions
-import securesystemslib.formats
-import securesystemslib.storage
+from securesystemslib import exceptions
+from securesystemslib import formats
+from securesystemslib.storage import FilesystemBackend
 
 
 DEFAULT_CHUNK_SIZE = 4096
@@ -47,9 +37,8 @@ SUPPORTED_LIBRARIES = ['hashlib']
 
 # If `pyca_crypto` is installed, add it to supported libraries
 try:
-  import cryptography.exceptions
-  import cryptography.hazmat.backends
-  import cryptography.hazmat.primitives.hashes as _pyca_hashes
+  from cryptography.hazmat.backends import default_backend
+  from cryptography.hazmat.primitives import hashes as _pyca_hashes
   import binascii
 
   # Dictionary of `pyca/cryptography` supported hash algorithms.
@@ -182,8 +171,8 @@ def digest(algorithm=DEFAULT_HASH_ALGORITHM, hash_library=DEFAULT_HASH_LIBRARY):
 
   # Are the arguments properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.NAME_SCHEMA.check_match(algorithm)
-  securesystemslib.formats.NAME_SCHEMA.check_match(hash_library)
+  formats.NAME_SCHEMA.check_match(algorithm)
+  formats.NAME_SCHEMA.check_match(hash_library)
 
   # Was a hashlib digest object requested and is it supported?
   # If so, return the digest object.
@@ -197,22 +186,21 @@ def digest(algorithm=DEFAULT_HASH_ALGORITHM, hash_library=DEFAULT_HASH_LIBRARY):
     except (ValueError, TypeError):
       # ValueError: the algorithm value was unknown
       # TypeError: unexpected argument digest_size (on old python)
-      raise securesystemslib.exceptions.UnsupportedAlgorithmError(algorithm)
+      raise exceptions.UnsupportedAlgorithmError(algorithm)
 
   # Was a pyca_crypto digest object requested and is it supported?
   elif hash_library == 'pyca_crypto' and hash_library in SUPPORTED_LIBRARIES:
     try:
       hash_algorithm = PYCA_DIGEST_OBJECTS_CACHE[algorithm]()
       return PycaDiggestWrapper(
-        cryptography.hazmat.primitives.hashes.Hash(hash_algorithm,
-            cryptography.hazmat.backends.default_backend()))
+        _pyca_hashes.Hash(hash_algorithm, default_backend()))
 
     except KeyError:
-      raise securesystemslib.exceptions.UnsupportedAlgorithmError(algorithm)
+      raise exceptions.UnsupportedAlgorithmError(algorithm)
 
   # The requested hash library is not supported.
   else:
-    raise securesystemslib.exceptions.UnsupportedLibraryError('Unsupported'
+    raise exceptions.UnsupportedLibraryError('Unsupported'
         ' library requested.  Supported hash'
         ' libraries: ' + repr(SUPPORTED_LIBRARIES))
 
@@ -270,8 +258,8 @@ def digest_fileobject(file_object, algorithm=DEFAULT_HASH_ALGORITHM,
 
   # Are the arguments properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.NAME_SCHEMA.check_match(algorithm)
-  securesystemslib.formats.NAME_SCHEMA.check_match(hash_library)
+  formats.NAME_SCHEMA.check_match(algorithm)
+  formats.NAME_SCHEMA.check_match(hash_library)
 
   # Digest object returned whose hash will be updated using 'file_object'.
   # digest() raises:
@@ -307,7 +295,7 @@ def digest_fileobject(file_object, algorithm=DEFAULT_HASH_ALGORITHM,
           .replace(b'\r', b'\n')
       )
 
-    if not isinstance(data, six.binary_type):
+    if not isinstance(data, bytes):
       digest_object.update(data.encode('utf-8'))
 
     else:
@@ -367,14 +355,14 @@ def digest_filename(filename, algorithm=DEFAULT_HASH_ALGORITHM,
   """
   # Are the arguments properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.PATH_SCHEMA.check_match(filename)
-  securesystemslib.formats.NAME_SCHEMA.check_match(algorithm)
-  securesystemslib.formats.NAME_SCHEMA.check_match(hash_library)
+  formats.PATH_SCHEMA.check_match(filename)
+  formats.NAME_SCHEMA.check_match(algorithm)
+  formats.NAME_SCHEMA.check_match(hash_library)
 
   digest_object = None
 
   if storage_backend is None:
-    storage_backend = securesystemslib.storage.FilesystemBackend()
+    storage_backend = FilesystemBackend()
 
   # Open 'filename' in read+binary mode.
   with storage_backend.get(filename) as file_object:
@@ -428,7 +416,7 @@ def digest_from_rsa_scheme(scheme, hash_library=DEFAULT_HASH_LIBRARY):
   """
   # Are the arguments properly formatted?  If not, raise
   # 'securesystemslib.exceptions.FormatError'.
-  securesystemslib.formats.RSA_SCHEME_SCHEMA.check_match(scheme)
+  formats.RSA_SCHEME_SCHEMA.check_match(scheme)
 
   # Get hash algorithm from rsa scheme (hash algorithm id is specified after
   # the last dash; e.g. rsassa-pss-sha256 -> sha256)
