@@ -47,14 +47,6 @@
   key (i.e., rsakey['keyid']).
  """
 
-# Help with Python 3 compatibility, where the print statement is a function, an
-# implicit relative import is invalid, and the '/' operator performs true
-# division.  Example:  print 'hello world' raises a 'SyntaxError' exception.
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 # Required for hexadecimal conversions.  Signatures and public/private keys are
 # hexlified.
 import binascii
